err_status_code

Function err_status_code 

pub fn err_status_code(err: &Error) -> Option<StatusCode>
If this error was due to a reqwest error created from an HTTP response, return the status code from that response. If the error is not a reqwest::Error, or was not caused by an HTTP response, returns None.