Struct taskcluster::ClientBuilder [−][src]
ClientBuilder implements the builder pattern for building a Client, allowing optional configuration of features such as authorized scopes and retry.
Implementations
impl ClientBuilder[src]
pub fn new<S: Into<String>>(root_url: S) -> Self[src]
Create a new ClientBuilder. The Taskcluster root URL is required and so must always be specified.
pub fn credentials(self, credentials: Credentials) -> Self[src]
Add credentials to the client
pub fn retry(self, retry: Retry) -> Self[src]
Set the retry configuration for the client
pub fn authorized_scopes(
self,
authorized_scopes: impl IntoIterator<Item = impl AsRef<str>>
) -> Self[src]
self,
authorized_scopes: impl IntoIterator<Item = impl AsRef<str>>
) -> Self
Set the authorized scopes for this client. These will be passed along with request, and included in signed URLs, and will act as a limit on the scopes available for the operation beyond those afforded by the credentials themselves.
pub fn build(self) -> Result<Client>[src]
Build the resulting client, consuming the builder